@@ -91,9 +91,7 @@ class ApplicationRunner(object):
 
     log = txaio.make_logger()
 
-    def __init__(self, url, realm, extra=None, serializers=None,
-                 debug=False, debug_wamp=False, debug_app=False,
-                 ssl=None, proxy=None):
+    def __init__(self, url, realm, extra=None, serializers=None, ssl=None, proxy=None):
         """
 
         :param url: The WebSocket URL of the WAMP router to connect to (e.g. `ws://somehost.com:8090/somepath`)
@@ -109,15 +107,6 @@ class ApplicationRunner(object):
            Serializers must implement :class:`autobahn.wamp.interfaces.ISerializer`.
         :type serializers: list
 
-        :param debug: Turn on low-level debugging.
-        :type debug: bool
-
-        :param debug_wamp: Turn on WAMP-level debugging.
-        :type debug_wamp: bool
-
-        :param debug_app: Turn on app-level debugging.
-        :type debug_app: bool
-
         :param ssl: (Optional). If specified this should be an
             instance suitable to pass as ``sslContextFactory`` to
             :class:`twisted.internet.endpoints.SSL4ClientEndpoint`` such
@@ -131,16 +120,13 @@ class ApplicationRunner(object):
         :type proxy: dict or None
         """
         assert(type(url) == six.text_type)
-        assert(type(realm) == six.text_type)
+        assert(realm is None or type(realm) == six.text_type)
         assert(extra is None or type(extra) == dict)
         assert(proxy is None or type(proxy) == dict)
         self.url = url
         self.realm = realm
         self.extra = extra or dict()
         self.serializers = serializers
-        self.debug = debug
-        self.debug_wamp = debug_wamp
-        self.debug_app = debug_app
         self.ssl = ssl
         self.proxy = proxy
 
@@ -171,11 +157,7 @@ class ApplicationRunner(object):
             from twisted.internet import reactor
             txaio.use_twisted()
             txaio.config.loop = reactor
-
-            if self.debug or self.debug_wamp or self.debug_app:
-                txaio.start_logging(level='debug')
-            else:
-                txaio.start_logging(level='info')
+            txaio.start_logging(level='info')
 
         isSecure, host, port, resource, path, params = parseWsUrl(self.url)
 
@@ -194,12 +176,14 @@ class ApplicationRunner(object):
                     # caller to deal with errors
                     raise
             else:
-                session.debug_app = self.debug_app
                 return session
 
         # create a WAMP-over-WebSocket transport client factory
-        transport_factory = WampWebSocketClientFactory(create, url=self.url, serializers=self.serializers,
-                                                       proxy=self.proxy, debug=self.debug, debug_wamp=self.debug_wamp)
+        transport_factory = WampWebSocketClientFactory(create, url=self.url, serializers=self.serializers, proxy=self.proxy)
+
+        # supress pointless log noise like
+        # "Starting factory <autobahn.twisted.websocket.WampWebSocketClientFactory object at 0x2b737b480e10>""
+        transport_factory.noisy = False
 
         # if user passed ssl= but isn't using isSecure, we'll never
         # use the ssl argument which makes no sense.
@@ -235,7 +219,10 @@ class ApplicationRunner(object):
         # fires when the transport gets to STATE_CLOSED
         def cleanup(proto):
             if hasattr(proto, '_session') and proto._session is not None:
-                return proto._session.leave()
+                if proto._session.is_attached():
+                    return proto._session.leave()
+                elif proto._session.is_connected():
+                    return proto._session.disconnect()
 
         # when our proto was created and connected, make sure it's cleaned
         # up properly later on when the reactor shuts down for whatever reason
@@ -258,7 +245,6 @@ class ApplicationRunner(object):
 
                 def __call__(self, failure):
                     self.exception = failure.value
-                    # print(failure.getErrorMessage())
                     reactor.stop()
             connect_error = ErrorCollector()
             d.addErrback(connect_error)
@@ -373,9 +359,7 @@ class Application(object):
         self.session = _ApplicationSession(config, self)
         return self.session
 
-    def run(self, url=u"ws://localhost:8080/ws", realm=u"realm1",
-            debug=False, debug_wamp=False, debug_app=False,
-            start_reactor=True):
+    def run(self, url=u"ws://localhost:8080/ws", realm=u"realm1", start_reactor=True):
         """
         Run the application.
 
@@ -383,16 +367,9 @@ class Application(object):
         :type url: unicode
         :param realm: The realm on the WAMP router to join.
         :type realm: unicode
-        :param debug: Turn on low-level debugging.
-        :type debug: bool
-        :param debug_wamp: Turn on WAMP-level debugging.
-        :type debug_wamp: bool
-        :param debug_app: Turn on app-level debugging.
-        :type debug_app: bool
         """
-        runner = ApplicationRunner(url, realm,
-                                   debug=debug, debug_wamp=debug_wamp, debug_app=debug_app)
-        runner.run(self.__call__, start_reactor)
+        runner = ApplicationRunner(url, realm)
+        return runner.run(self.__call__, start_reactor)
 
     def register(self, uri=None):
         """
@@ -562,8 +539,7 @@ if service:
         """
         factory = WampWebSocketClientFactory
 
-        def __init__(self, url, realm, make, extra=None, context_factory=None,
-                     debug=False, debug_wamp=False, debug_app=False):
+        def __init__(self, url, realm, make, extra=None, context_factory=None):
             """
 
             :param url: The WebSocket URL of the WAMP router to connect to (e.g. `ws://somehost.com:8090/somepath`)
@@ -583,24 +559,12 @@ if service:
                 the ``listenSSL()`` call; see https://twistedmatrix.com/documents/current/api/twisted.internet.interfaces.IReactorSSL.connectSSL.html
             :type context_factory: twisted.internet.ssl.ClientContextFactory or None
 
-            :param debug: Turn on low-level debugging.
-            :type debug: bool
-
-            :param debug_wamp: Turn on WAMP-level debugging.
-            :type debug_wamp: bool
-
-            :param debug_app: Turn on app-level debugging.
-            :type debug_app: bool
-
             You can replace the attribute factory in order to change connectionLost or connectionFailed behaviour.
             The factory attribute must return a WampWebSocketClientFactory object
             """
             self.url = url
             self.realm = realm
             self.extra = extra or dict()
-            self.debug = debug
-            self.debug_wamp = debug_wamp
-            self.debug_app = debug_app
             self.make = make
             self.context_factory = context_factory
             service.MultiService.__init__(self)
@@ -616,12 +580,10 @@ if service:
             def create():
                 cfg = ComponentConfig(self.realm, self.extra)
                 session = self.make(cfg)
-                session.debug_app = self.debug_app
                 return session
 
             # create a WAMP-over-WebSocket transport client factory
-            transport_factory = self.factory(create, url=self.url,
-                                             debug=self.debug, debug_wamp=self.debug_wamp)
+            transport_factory = self.factory(create, url=self.url)
 
             # setup the client from a Twisted endpoint
 
